@@ -10,11 +10,11 @@ Generic or specific utilities  without polluting imports.
 """
 
 import abc
+import inspect
 import logging
 from collections import defaultdict, namedtuple
 from functools import partial, partialmethod, wraps
-from typing import Any, Collection, List, Mapping, NamedTuple, Optional
-from typing import Tuple, Union
+from typing import Any, Collection, List, Mapping, NamedTuple, Optional, Tuple, Union
 
 Items = Union[Collection, str, None]
 
@@ -157,18 +157,21 @@ def func_name(fn, default=..., mod=None, fqdn=None, human=None) -> Optional[str]
 
     TBD
     """
+
     if isinstance(fn, (partial, partialmethod)):
         # Always bubble-up errors.
         fn_name = func_name(fn.func, default, mod, fqdn, human)
         if human:
-            args = [str(i) for i in (fn.args, fn.keywords) if i]
-            args.append("...")
-            args_str = ", ".join(args)
+            args = ", ".join(str(i) for i in fn.args)
+            kw = ", ".join(f"{k}={v}" for k, v in fn.keywords.items())
+            args_str = ", ".join(i for i in (args, kw) + ("...",) if i)
             fn_name = f"{fn_name}({args_str})"
 
         return fn_name
 
     try:
+        if human and inspect.isbuiltin(fn):
+            return str(fn)
         fn_name = fn.__qualname__ if fqdn else fn.__name__
         assert fn_name
 
@@ -193,7 +196,7 @@ def _un_partial_ize(func):
     @wraps(func)
     def wrapper(fn, *args, **kw):
         if isinstance(fn, (partial, partialmethod)):
-            return func(fn.func, *args, **kw)
+            fn = fn.func
         return func(fn, *args, **kw)
 
     return wrapper
@@ -210,11 +213,12 @@ def func_source(fn, default=..., human=None) -> Optional[Tuple[str, int]]:
     :param human:
         when true, denote builtins like python does
     """
-    import inspect
-
     try:
-        if human and inspect.isbuiltin(fn):
-            return str(fn)
+        if inspect.isbuiltin(fn):
+            if human:
+                return inspect.getdoc(fn).splitlines()[0]
+            else:
+                return str(fn)
         return inspect.getsource(fn)
     except Exception as ex:
         if default is ...:
@@ -234,8 +238,6 @@ def func_sourcelines(fn, default=..., human=None) -> Optional[Tuple[str, int]]:
         If given, better be a 2-tuple respecting types,
         or ``...``, to raise.
     """
-    import inspect
-
     try:
         if human and inspect.isbuiltin(fn):
             return [str(fn)], -1
@@ -351,23 +353,35 @@ def jetsam(ex, locs, *salvage_vars: str, annotation="jetsam", **salvage_mappings
         raise ex2
 
 
-_PlotArgs_render_args = {"filename", "show", "jupyter_render"}
-
-
 class PlotArgs(NamedTuple):
-    """All the args of a :meth:`.Plottable.plot()` call. """
+    """
+    All the args of a :meth:`.Plottable.plot()` call,
 
-    plotter: "Plotter" = None
+    check this method for a more detailed  explanation of its attributes.
+    """
+
+    #: who is the caller
+    plottable: "Plottable" = None
+    #: what to plot (or the "overlay" when calling :meth:`Plottable.plot()`)
     graph: "nx.Graph" = None
+    #: The name of the graph in the dot-file (important for cmaps).
     name: str = None
+    #: the list of execution plan steps.
     steps: Collection = None
+    #: the list of input names .
     inputs: Collection = None
+    #: the list of output names .
     outputs: Collection = None
+    #: Contains the computed results, which might be different from :attr:`plottable`.
     solution: "Solution" = None
+    #: a mapping of nodes to cluster names
     clusters: Mapping = None
+    #: if given, overrides :active plotter`
+    plotter: "Plotter" = None
+    #: jupyter configuration overrides
     jupyter_render: Mapping = None
-    filename: str = None
-    show: Union[bool, int] = None
+    #: where to write image or show in a matplotlib window
+    filename: Union[str, bool, int] = None
 
     def clone_or_merge_graph(self, base_graph) -> "PlotArgs":
         """
@@ -376,9 +390,10 @@ class PlotArgs(NamedTuple):
         :return:
             the updated plot_args
         """
-        import networkx as nx
 
         if self.graph:
+            import networkx as nx
+
             graph = nx.compose(base_graph, self.graph)
         else:
             graph = base_graph.copy()  # cloned, to freely annotate downstream
@@ -391,17 +406,9 @@ class PlotArgs(NamedTuple):
             **{k: v for k, v in dict(*args, **kw).items() if getattr(self, k) is None}
         )
 
-    @property
-    def kw_build_pydot(self) -> dict:
-        return {
-            k: v
-            for k, v in self._asdict().items()
-            if k not in _PlotArgs_render_args and k != "plotter"
-        }
-
     @property
     def kw_render_pydot(self) -> dict:
-        return {k: v for k, v in self._asdict().items() if k in _PlotArgs_render_args}
+        return {k: getattr(self, k) for k in self._fields[-2:]}
 
 
 ## Defined here, to avoid subclasses importing `plot` module.
@@ -417,8 +424,8 @@ class Plottable(abc.ABC):
 
     def plot(
         self,
-        filename=None,
-        show=False,
+        filename: Union[str, bool, int] = None,
+        show=None,
         *,
         plotter: "Plotter" = None,
         graph: "networkx.Graph" = None,
@@ -434,19 +441,39 @@ class Plottable(abc.ABC):
         Entry-point for plotting ready made operation graphs.
 
         :param str filename:
-            Write diagram into a file.
-            Common extensions are ``.png .dot .jpg .jpeg .pdf .svg``
-            call :func:`.plot.supported_plot_formats()` for more.
-        :param show:
-            If it evaluates to true, opens the  diagram in a  matplotlib window.
-            If it equals `-1`, it plots but does not open the Window.
+            Write a file or open a `matplotlib` window.
+
+            - If it is a string or file, the diagram is written into the file-path
+
+              Common extensions are ``.png .dot .jpg .jpeg .pdf .svg``
+              call :func:`.plot.supported_plot_formats()` for more.
+
+            - If it IS `True`, opens the  diagram in a  matplotlib window
+              (requires `matplotlib` package to be installed).
+
+            - If it equals `-1`, it mat-plots but does not open the window.
+
+            - Otherwise, just return the ``pydot.Dot`` instance.
+
+            :seealso: :attr:`.PlotArgs.filename`, :meth:`.Plotter.render_pydot()`
+        :param plottable:
+            the :term:`plottable` that ordered the plotting.
+            Automatically set downstreams to one of::
+
+                netop | net | plan | solution | <missing>
+
+            :seealso: :attr:`.PlotArgs.plottable`
         :param plotter:
-            an instance to handle plotting; if none, the :term:`active plotter`
+            the :term:`plotter` to handle plotting; if none, the :term:`active plotter`
             is used by default.
+
+            :seealso: :attr:`.PlotArgs.plotter`
         :param name:
             if not given, dot-lang graph would is named "G"; necessary to be unique
             when referring to generated CMAPs.
             No need to quote it, handled by the plotter, downstream.
+
+            :seealso: :attr:`.PlotArgs.name`
         :param str graph:
             (optional) A :class:`nx.Digraph` with overrides to merge with the graph provided
             by underlying plottables (translated by the :term:`active plotter`).
@@ -456,35 +483,42 @@ class Plottable(abc.ABC):
             - "private" attributes: those starting with underscore(``_``),
               handled by :term:`plotter`:
 
-              - ``_source`` *(graph)*: a non user-overridable attribute with values
-                used to select plotter-styles::
-
-                    netop | net | plan | solution | <'_source` missing>
               - ``_fn_link_target`` & ``_fn_link_target`` *(node)*: if truthy,
                 override result 2-tuple of :meth:`_get_fn_link()`.
               - ``_op_tooltip`` & ``_fn_tooltip`` *(node)*: if truthy,
                 override those derrived from :meth:`_make_op_tooltip()` &
                 :meth:`_make_op_tooltip()`.
+              - ``_no_plot``: nodes and/or edges skipped from plotting
+                (see *"Examples:"* section, below)
 
-            - "public" attributes: reaching `Graphviz`_ as-is.
+            - "public" attributes: reaching `Graphviz`_ as-is, e.g.
+              to set ``spline -> ortho`` on the graph attributes
+              (this can also be achieved by modified :term:`plot styles`).
 
               .. Note::
 
                 Remember to escape those values as `Graphviz`_ HTML-Like strings
                 (use :func:`.plot.graphviz_html_string()`).
 
+            :seealso: :attr:`.PlotArgs.graph`
         :param inputs:
             an optional name list, any nodes in there are plotted
             as a "house"
+
+            :seealso: :attr:`.PlotArgs.inputs`
         :param outputs:
             an optional name list, any nodes in there are plotted
             as an "inverted-house"
+
+            :seealso: :attr:`.PlotArgs.outputs`
         :param solution:
             an optional dict with values to annotate nodes, drawn "filled"
             (currently content not shown, but node drawn as "filled").
             It extracts more infos from a :class:`.Solution` instance, such as,
             if `solution` has an ``executed`` attribute, operations contained in it
             are  drawn as "filled".
+
+            :seealso: :attr:`.PlotArgs.solution`
         :param clusters:
             an optional mapping of nodes --> cluster-names, to group them
         :param jupyter_render:
@@ -492,6 +526,11 @@ class Plottable(abc.ABC):
             if `None`, defaults to :data:`jupyter_render`; you may modify it in place
             and apply for all future calls (see :ref:`jupyter_rendering`).
 
+            :seealso: :attr:`.PlotArgs.jupyter_render`
+        :param show:
+            .. deprecated:: v6.1.1
+                Merged with `filename` param (filename takes precedence).
+
         :return:
             a |pydot.Dot|_ instance
             (for reference to as similar API to |pydot.Dot|_ instance, visit:
@@ -542,10 +581,10 @@ class Plottable(abc.ABC):
         green-dotted arrows
             execution steps labeled in succession
 
-
         To generate the **legend**, see :func:`.legend()`.
 
-        **Sample code:**
+
+        **Examples:**
 
         >>> from graphtik import compose, operation
         >>> from graphtik.modifiers import optional
@@ -557,23 +596,49 @@ class Plottable(abc.ABC):
         ...     operation(name="abb", needs=["ab1", "ab2"], provides=["asked"])(add),
         ... )
 
-        >>> netop.plot(show=True);                 # plot just the graph in a matplotlib window # doctest: +SKIP
+        >>> netop.plot(True);                       # plot just the graph in a matplotlib window # doctest: +SKIP
         >>> inputs = {'a': 1, 'b1': 2}
-        >>> solution = netop(**inputs)             # now plots will include the execution-plan
+        >>> solution = netop(**inputs)              # now plots will include the execution-plan
 
         >>> netop.plot('plot1.svg', inputs=inputs, outputs=['asked', 'b1'], solution=solution);           # doctest: +SKIP
-        >>> dot = netop.plot(solution=solution);   # just get the `pydot.Dot` object, renderable in Jupyter
+        >>> dot = netop.plot(solution=solution);    # just get the `pydot.Dot` object, renderable in Jupyter
         >>> print(dot)
         digraph netop {
         fontname=italic;
         label=<netop>;
-        splines=ortho;
         <a> [fillcolor=wheat, shape=invhouse, style=filled, tooltip="(int) 1"];
         ...
 
+        .. TODO: move advanced plot examples from API --> tutorial page
+
+        You may use the :attr:`PlotArgs.graph` overlay to skip certain nodes (or edges)
+        from the plots:
+
+        >>> import networkx as nx
+
+        >>> g = nx.DiGraph()  # the overlay
+        >>> to_hide = netop.net.find_op_by_name("sub")
+        >>> g.add_node(to_hide, _no_plot=True)
+        >>> dot = netop.plot(graph=g)
+        >>> assert "<sub>" not in str(dot), str(dot)
+
+        .. graphtik::
+
         """
         kw = locals().copy()
+
         del kw["self"]
+        show = kw.pop("show", None)
+        if show:
+            import warnings
+
+            warnings.warn(
+                "Argument `plot` has merged with `filename` and will be deleted soon.",
+                DeprecationWarning,
+            )
+            if not filename:
+                kw["filename"] = show
+
         plot_args = PlotArgs(**kw)
 
         from .plot import Plotter, get_active_plotter
