@@ -255,7 +255,7 @@ class NetworkOperation(Operation, Plottable):
         assert plot_args.graph, plot_args
 
         plot_args.graph.graph.setdefault("label", graphviz_html_string(self.name))
-        plot_args.graph.graph["_source"] = "netop"
+        plot_args = plot_args._replace(plottable=self)
 
         return plot_args
 
