@@ -342,7 +342,7 @@ class Solution(ChainMap, Plottable):
         name = f"solution-x{len(self.plan.net.graph.nodes)}-nodes"
         plot_args = plot_args.with_defaults(name=name, solution=self)
         plot_args = self.plan.prepare_plot_args(plot_args)
-        plot_args.graph.graph["_source"] = "solution"
+        plot_args = plot_args._replace(plottable=self)
 
         return plot_args
 
@@ -510,14 +510,16 @@ class ExecutionPlan(
         if self.dag.nodes != graph.nodes:
             clusters = {n: "after pruning" for n in self.dag.nodes}
 
-        graph.graph["_source"] = "plan"
-        return plot_args.with_defaults(
+        plot_args = plot_args.with_defaults(
             name=f"plan-x{len(graph.nodes)}-nodes",
             steps=self.steps,
             inputs=self.needs,
             outputs=self.provides,
             clusters=clusters,
         )
+        plot_args = plot_args._replace(plottable=self)
+
+        return plot_args
 
     def __repr__(self):
         needs = aslist(self.needs, "needs")
@@ -938,14 +940,35 @@ class Network(Plottable):
         )
         return f"Network(x{len(self.graph.nodes)} nodes, x{len(ops)} ops: {''.join(steps)})"
 
+    def find_ops(self, predicate) -> List[Operation]:
+        """
+        Scan operation nodes and fetch those satisfying `predicate`.
+
+        :param predicate:
+            the :term:`node predicate` is a 2-argument callable(op, node-data)
+            that should return true for nodes to include.
+        """
+        return [
+            n
+            for n, d in self.graph.nodes.data(True)
+            if isinstance(n, Operation) and predicate(n, d)
+        ]
+
+    def find_op_by_name(self, name) -> Union[Operation, None]:
+        """Fetch the 1st operation named with the given `name`."""
+        for n in yield_ops(self.graph.nodes):
+            if n.name == name:
+                return n
+
     def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
         plot_args = plot_args.clone_or_merge_graph(self.graph)
-        plot_args.with_defaults(
+        plot_args = plot_args.with_defaults(
             name=f"network-x{len(self.graph.nodes)}-nodes",
             inputs=self.needs,
             outputs=self.provides,
         )
-        plot_args.graph.graph["_source"] = "net"
+        plot_args = plot_args._replace(plottable=self)
+
         return plot_args
 
     def _append_operation(self, graph, operation: Operation):
