@@ -18,7 +18,17 @@ from collections import namedtuple
 from contextlib import contextmanager
 from contextvars import ContextVar
 from functools import partial
-from typing import Any, Callable, List, Mapping, NamedTuple, Optional, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Collection,
+    List,
+    Mapping,
+    NamedTuple,
+    Optional,
+    Tuple,
+    Union,
+)
 
 import jinja2
 import networkx as nx
@@ -27,7 +37,8 @@ from boltons.iterutils import remap
 
 from .base import PlotArgs, func_name, func_source
 from .modifiers import optional
-from .network import _EvictInstruction
+from .netop import NetworkOperation
+from .network import ExecutionPlan, Network, Solution, _EvictInstruction
 from .op import Operation
 
 log = logging.getLogger(__name__)
@@ -329,13 +340,14 @@ class Style:
     ## VARIABLES
 
     fill_color = "wheat"
+    pruned_color = "LightGrey"
+    canceled_color = "DarkGrey"
     failed_color = "LightCoral"
     resched_thickness = 4
-    cancel_color = "Grey"
     broken_color = "Red"
     overwrite_color = "SkyBlue"
     steps_color = "#009999"
-    in_plan = "#000099"
+    evicted = "#000099"
     #: See :meth:`.Plotter._make_py_item_link()`.
     py_item_url_format: Union[str, Callable[[str], str]] = None
     #: the url to the architecture section explaining *graphtik* glossary,
@@ -348,19 +360,22 @@ class Style:
     kw_graph = {
         "graph_type": "digraph",
         "fontname": "italic",
-        # Whether to plot `curved/polyline edges
-        # <https://graphviz.gitlab.io/_pages/doc/info/attrs.html#d:splines>`_
-        "splines": "ortho",
+        ## Whether to plot `curved/polyline edges
+        #  <https://graphviz.gitlab.io/_pages/doc/info/attrs.html#d:splines>`_
+        #  BUT disabled due to crashes:
+        #  https://gitlab.com/graphviz/graphviz/issues/1408
+        #"splines": "ortho",
     }
     #: styles per plot-type
-    kw_graph_type = {
-        "netop": {},
-        "net": {},
-        "plan": {},
-        "solution": {},
-        # nx-graphs without ``_source`` graph-attr
-        None: {},
+    kw_pottable_type = {
+        "NetworkOperation": {},
+        "Network": {},
+        "ExecutionPlan": {},
+        "Solution": {},
     }
+    #: For when type-name of :attr:`PlotArgs.plottable` is not found
+    #: in :attr:`.kw_plottable_type` ( ot missing altogether).
+    kw_pottable_type_unknown = {}
     kw_graph_netop = {}
     kw_graph_net = {}
     kw_graph_plan = {}
@@ -371,13 +386,15 @@ class Style:
 
     kw_data = {}
     kw_data_pruned = {
-        "color": Ref("cancel_color"),
-        "tooltip": "(pruned node)",
-        "fontcolor": Ref("cancel_color"),
+        "fontcolor": Ref("pruned_color"),
+        "color": Ref("pruned_color"),
+        "tooltip": "(pruned)",
     }
-    kw_data_in_plan = {"color": Ref("in_plan")}
+    kw_data_to_evict = {}
     kw_data_in_solution = {"style": "filled", "fillcolor": Ref("fill_color")}
+    kw_data_evicted = {"color": Ref("evicted"), "tooltip": "(evicted)"}
     kw_data_overwritten = {"style": "filled", "fillcolor": Ref("overwrite_color")}
+    kw_data_canceled = {"fillcolor": Ref("canceled_color"), "tooltip": "(canceled)"}
 
     ##########
     ## OPERATION node
@@ -391,12 +408,12 @@ class Style:
     kw_op = {}
     #: props only for HTML-Table label
     kw_op_label = {}
-    kw_op_pruned = {"color": Ref("cancel_color"), "fontcolor": Ref("cancel_color")}
+    kw_op_pruned = {"color": Ref("pruned_color"), "fontcolor": Ref("pruned_color")}
     kw_op_executed = {"fillcolor": Ref("fill_color")}
     kw_op_rescheduled = {"penwidth": Ref("resched_thickness")}
     kw_op_endured = {"penwidth": Ref("resched_thickness")}
     kw_op_failed = {"fillcolor": Ref("failed_color")}
-    kw_op_canceled = {"fillcolor": Ref("cancel_color")}
+    kw_op_canceled = {"fillcolor": Ref("canceled_color")}
     #: Applied only if :attr:`py_item_url_format` defined, or
     #: ``"_op_link_target"`` in nx_node-attributes.
 
@@ -569,8 +586,14 @@ class Plotter:
         if graph is None:
             raise ValueError("At least `graph` to plot must be given!")
 
+        graph, steps = self._skip_nodes(graph, steps)
+
         kw = style.kw_graph.copy()
-        kw.update(style.kw_graph_type[graph.graph.get("_source")])
+        kw.update(
+            style.kw_pottable_type.get(
+                type(plot_args.plottable).__name__, style.kw_pottable_type_unknown,
+            )
+        )
         kw.update(_pub_props(graph.graph))
         dot = pydot.Dot(**kw)
 
@@ -580,7 +603,7 @@ class Plotter:
         ## NODES
         #
         base_node_args = node_args = NodeArgs(dot=dot, clustered={})
-        for nx_node, data in graph.nodes(data=True):
+        for nx_node, data in graph.nodes.data(True):
             node_args = base_node_args._replace(nx_node=nx_node, node_attrs=data)
 
             dot_node = self._make_node(plot_args, node_args)
@@ -591,7 +614,7 @@ class Plotter:
 
         ## EDGES
         #
-        for src, dst, data in graph.edges(data=True):
+        for src, dst, data in graph.edges.data(True):
             src_name = get_node_name(src)
             dst_name = get_node_name(dst)
 
@@ -668,13 +691,12 @@ class Plotter:
         """
         from .op import Operation
 
+        style = self.style
         nx_node = node_args.nx_node
         node_attrs = node_args.node_attrs
-        inputs = plot_args.inputs
-        outputs = plot_args.outputs
-        steps = plot_args.steps
-        solution = plot_args.solution
-        style = self.style
+        (plottable, _, _, steps, inputs, outputs, solution, *_,) = plot_args
+        if solution is None and isinstance(plottable, Solution):
+            solution = plottable
 
         if isinstance(nx_node, str):  # DATA
             # SHAPE change if with inputs/outputs.
@@ -684,13 +706,30 @@ class Plotter:
             )
             shape = "rect invhouse house hexagon".split()[choice]
 
-            kw = {
-                "name": quote_node_id(nx_node),
-                "shape": shape,
-            }
+            kw = style.kw_data.copy()
+            kw.update(
+                {"name": quote_node_id(nx_node), "shape": shape,}
+            )
 
-            if steps and nx_node in steps:
-                kw.update(style.kw_data_in_plan)
+            is_pruned = (
+                (
+                    isinstance(plottable, ExecutionPlan)
+                    and nx_node not in plottable.dag.nodes
+                )
+                or (
+                    isinstance(plottable, Solution)
+                    and nx_node not in plottable.dag.nodes
+                )
+                or (solution and nx_node not in solution.dag.nodes)
+            )
+
+            if is_pruned:
+                assert (
+                    not steps or nx_node not in steps
+                ), f"Given `steps` missmatch `plan` and/or `solution`!\n  {plot_args}"
+                kw.update(**style.kw_data_pruned)
+            elif steps and nx_node in steps:
+                kw.update(style.kw_data_to_evict)
 
             if solution is not None:
                 if nx_node in solution:
@@ -698,12 +737,11 @@ class Plotter:
                     if nx_node in solution.overwrites:
                         kw.update(style.kw_data_overwritten)
 
-                if nx_node not in solution.plan.dag.nodes:
-                    kw.update(**style.kw_data_pruned)
-                else:
                     val = solution.get(nx_node)
                     tooltip = "None" if val is None else f"({type(val).__name__}) {val}"
                     kw["tooltip"] = quote_html_tooltips(tooltip)
+                elif not is_pruned:
+                    kw.update(**style.kw_data_canceled)
 
             kw.update(_pub_props(node_attrs))
 
@@ -859,21 +897,47 @@ class Plotter:
         if kw_legend and self.style.kw_legend.get("URL"):
             node_args.dot.add_node(pydot.Node(**kw_legend))
 
-    def render_pydot(
-        self, dot: pydot.Dot, filename=None, show=False, jupyter_render: str = None
-    ):
+    def _skip_nodes(
+        self, graph: nx.Graph, steps: Collection
+    ) -> Tuple[nx.Graph, Collection]:
+        ## Drop any nodes, steps & edges with "_no_plot" attribute.
+        #
+        nodes_to_del = {n for n, no_plot in graph.nodes.data("_no_plot") if no_plot}
+        graph.remove_nodes_from(nodes_to_del)
+        if steps:
+            steps = [s for s in steps if s not in nodes_to_del]
+        graph.remove_edges_from(
+            [
+                (src, dst)
+                for src, dst, no_plot in graph.edges.data("_no_plot")
+                if no_plot
+            ]
+        )
+
+        return graph, steps
+
+    def render_pydot(self, dot: pydot.Dot, filename=None, jupyter_render: str = None):
         """
         Render a |pydot.Dot|_ instance with `Graphviz`_ in a file and/or in a matplotlib window.
 
         :param dot:
             the pre-built |pydot.Dot|_ instance
         :param str filename:
-            Write diagram into a file.
-            Common extensions are ``.png .dot .jpg .jpeg .pdf .svg``
-            call :func:`.supported_plot_formats()` for more.
-        :param show:
-            If it evaluates to true, opens the  diagram in a  matplotlib window.
-            If it equals `-1`, it returns the image but does not open the Window.
+            Write a file or open a `matplotlib` window.
+
+            - If it is a string or file, the diagram is written into the file-path
+
+              Common extensions are ``.png .dot .jpg .jpeg .pdf .svg``
+              call :func:`.plot.supported_plot_formats()` for more.
+
+            - If it IS `True`, opens the  diagram in a  matplotlib window
+              (requires `matplotlib` package to be installed).
+
+            - If it equals `-1`, it mat-plots but does not open the window.
+
+            - Otherwise, just return the ``pydot.Dot`` instance.
+
+            :seealso: :attr:`.PlotArgs.filename`
         :param jupyter_render:
             a nested dictionary controlling the rendering of graph-plots in Jupyter cells.
             If `None`, defaults to :data:`default_jupyter_render`;  you may modify those
@@ -883,16 +947,30 @@ class Plotter:
             something like this::
 
                 netop.plot(jupyter_render={"svg_element_styles": "height: 600px; width: 100%"})
-
         :return:
-            the matplotlib image if ``show=-1``, or the given `dot` annotated with any
+            the matplotlib image if ``filename=-1``, or the given `dot` annotated with any
             jupyter-rendering configurations given in `jupyter_render` parameter.
 
         See :meth:`.Plottable.plot()` for sample code.
         """
-        # Save plot
-        #
-        if filename:
+        if isinstance(filename, (bool, int)):
+            ## Display graph via matplotlib
+            #
+            import matplotlib.pyplot as plt
+            import matplotlib.image as mpimg
+
+            png = dot.create_png()
+            sio = io.BytesIO(png)
+            img = mpimg.imread(sio)
+            if filename != -1:
+                plt.imshow(img, aspect="equal")
+                plt.show()
+
+            return img
+
+        elif filename:
+            ## Save plot
+            #
             formats = supported_plot_formats()
             _basename, ext = os.path.splitext(filename)
             if not ext.lower() in formats:
@@ -903,27 +981,12 @@ class Plotter:
 
             dot.write(filename, format=ext.lower()[1:])
 
-        ## Display graph via matplotlib
-        #
-        if show:
-            import matplotlib.pyplot as plt
-            import matplotlib.image as mpimg
-
-            png = dot.create_png()
-            sio = io.BytesIO(png)
-            img = mpimg.imread(sio)
-            if show != -1:
-                plt.imshow(img, aspect="equal")
-                plt.show()
-
-            return img
-
         ## Propagate any properties for rendering in Jupyter cells.
         dot._jupyter_render = jupyter_render
 
         return dot
 
-    def legend(self, filename=None, show=None, jupyter_render: Mapping = None):
+    def legend(self, filename=None, jupyter_render: Mapping = None):
         """
         Generate a legend for all plots (see :meth:`.Plottable.plot()` for args)
 
@@ -973,7 +1036,7 @@ class Plotter:
             inp_out [shape=hexagon label="inp+out"
                     tooltip="Data both given and asked."
                     URL="%(arch_url)s#term-netop"];
-            evicted [shape=rect color="%(in_plan)s"
+            evicted [shape=rect color="%(evicted)s"
                     tooltip="Instruction step to erase data from solution, to save memory."
                     URL="%(arch_url)s#term-evictions"];
             sol     [shape=rect style=filled fillcolor=wheat label="in solution"
@@ -1020,7 +1083,7 @@ class Plotter:
         # nodes = dot.Node()
         # cluster.add_node("operation")
 
-        return self.render_pydot(dot, filename=filename, show=show)
+        return self.render_pydot(dot, filename=filename, jupyter_render=jupyter_render)
 
 
 def legend(
@@ -1031,11 +1094,24 @@ def legend(
 
     :param plotter:
         override the :term:`active plotter`
+    :param show:
+        .. deprecated:: v6.1.1
+            Merged with `filename` param (filename takes precedence).
 
     See :meth:`Plotter.render_pydot` for the rest arguments.
     """
+    if show:
+        import warnings
+
+        warnings.warn(
+            "Argument `plot` has merged with `filename` and will be deleted soon.",
+            DeprecationWarning,
+        )
+        if not filename:
+            filename = show
+
     plotter = plotter or get_active_plotter()
-    return plotter.legend(filename, show, jupyter_render)
+    return plotter.legend(filename, jupyter_render)
 
 
 def supported_plot_formats() -> List[str]:
