@@ -238,14 +238,14 @@ class _Foo:
         #
         ({"mod": 0, "fqdn": 0, "human": 0}, "eval"),
         ({"mod": 1, "fqdn": 0, "human": 0}, "builtins.eval"),
-        ({"mod": 0, "fqdn": 0, "human": 1}, "eval"),
-        ({"mod": 1, "fqdn": 0, "human": 1}, "builtins.eval"),
+        ({"mod": 0, "fqdn": 0, "human": 1}, "<built-in function eval>"),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "<built-in function eval>"),
         ## FQDN = 1
         #
         ({"mod": 0, "fqdn": 1, "human": 0}, "eval"),
         ({"mod": 1, "fqdn": 1, "human": 0}, "builtins.eval"),
-        ({"mod": 0, "fqdn": 1, "human": 1}, "eval"),
-        ({"mod": 1, "fqdn": 1, "human": 1}, "builtins.eval"),
+        ({"mod": 0, "fqdn": 1, "human": 1}, "<built-in function eval>"),
+        ({"mod": 1, "fqdn": 1, "human": 1}, "<built-in function eval>"),
     ],
 )
 def test_func_name_builtin(kw, exp):
@@ -301,14 +301,14 @@ def test_func_name_partial_empty(kw, exp):
         #
         ({"mod": 0, "fqdn": 0, "human": 0}, "_foo"),
         ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base._foo"),
-        ({"mod": 0, "fqdn": 0, "human": 1}, "_foo((1,), {'a': 2}, ...)"),
-        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base._foo((1,), {'a': 2}, ...)"),
+        ({"mod": 0, "fqdn": 0, "human": 1}, "_foo(1, a=2, ...)"),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base._foo(1, a=2, ...)"),
         ## FQDN = 1
         #
         ({"mod": 0, "fqdn": 1, "human": 0}, "_foo"),
         ({"mod": 1, "fqdn": 1, "human": 0}, "test.test_base._foo"),
-        ({"mod": 0, "fqdn": 1, "human": 1}, "_foo((1,), {'a': 2}, ...)"),
-        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._foo((1,), {'a': 2}, ...)"),
+        ({"mod": 0, "fqdn": 1, "human": 1}, "_foo(1, a=2, ...)"),
+        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._foo(1, a=2, ...)"),
     ],
 )
 def test_func_name_partial_args(kw, exp):
@@ -322,20 +322,14 @@ def test_func_name_partial_args(kw, exp):
         #
         ({"mod": 0, "fqdn": 0, "human": 0}, "_foo"),
         ({"mod": 1, "fqdn": 0, "human": 0}, "test.test_base._foo"),
-        ({"mod": 0, "fqdn": 0, "human": 1}, "_foo((1,), {'a': 2, 'b': 3}, ...)"),
-        (
-            {"mod": 1, "fqdn": 0, "human": 1},
-            "test.test_base._foo((1,), {'a': 2, 'b': 3}, ...)",
-        ),
+        ({"mod": 0, "fqdn": 0, "human": 1}, "_foo(1, a=2, b=3, ...)"),
+        ({"mod": 1, "fqdn": 0, "human": 1}, "test.test_base._foo(1, a=2, b=3, ...)",),
         ## FQDN = 1
         #
         ({"mod": 0, "fqdn": 1, "human": 0}, "_foo"),
         ({"mod": 1, "fqdn": 1, "human": 0}, "test.test_base._foo"),
-        ({"mod": 0, "fqdn": 1, "human": 1}, "_foo((1,), {'a': 2, 'b': 3}, ...)"),
-        (
-            {"mod": 1, "fqdn": 1, "human": 1},
-            "test.test_base._foo((1,), {'a': 2, 'b': 3}, ...)",
-        ),
+        ({"mod": 0, "fqdn": 1, "human": 1}, "_foo(1, a=2, b=3, ...)"),
+        ({"mod": 1, "fqdn": 1, "human": 1}, "test.test_base._foo(1, a=2, b=3, ...)",),
     ],
 )
 def test_func_name_partial_x2(kw, exp):
@@ -465,8 +459,15 @@ def test_func_source_method(fn):
 
 
 @pytest.mark.parametrize("fn", [eval, fnt.partial(eval)])
-def test_func_source_builtin(fn):
-    exp = "<built-in function eval>"
+def test_func_source_builtin_id(fn):
+    exp = str(eval)
+    got = base.func_source(fn, human=0)
+    assert got == exp
+
+
+@pytest.mark.parametrize("fn", [eval, fnt.partial(eval)])
+def test_func_source_builtin_human(fn):
+    exp = "Evaluate the given source in the context of globals and locals."
     got = base.func_source(fn, human=1)
     assert got == exp
 
