@@ -8,6 +8,7 @@ from functools import partial
 from operator import add
 
 import dill
+import networkx as nx
 import pytest
 
 from graphtik import base, compose, network, operation, plot
@@ -16,8 +17,8 @@ from graphtik.netop import NetworkOperation
 from graphtik.plot import (
     Plotter,
     Style,
-    get_active_plotter,
     active_plotter_plugged,
+    get_active_plotter,
 )
 
 
@@ -300,7 +301,7 @@ def test_plot_matpotlib(pipeline, tmp_path):
     ## Try matplotlib Window, but # without opening a Window.
 
     # do not open window in headless travis
-    img = pipeline.plot(show=-1)
+    img = pipeline.plot(filename=-1)
     _check_plt_img(img)
 
 
@@ -318,7 +319,7 @@ def test_plot_legend(pipeline, tmp_path):
     dot = plot.legend()
     assert dot
 
-    img = plot.legend(show=-1)
+    img = plot.legend(filename=-1)
     _check_plt_img(img)
 
 
@@ -405,7 +406,7 @@ def test_plotter_dill():
     dill.dumps(plotter)
 
 
-def func():
+def func(a, b):
     pass
 
 
@@ -422,6 +423,9 @@ def dot_str_pipeline():
     )
 
 
+@pytest.mark.xfail(
+    sys.version_info < (3, 7), reason="PY3.6- have different docstrings for builtins."
+)
 def test_node_dot_str0(dot_str_pipeline):
     dot_str = str(dot_str_pipeline.plot())
     print(dot_str)
@@ -429,25 +433,24 @@ def test_node_dot_str0(dot_str_pipeline):
         digraph graph_ {
         fontname=italic;
         label=<graph>;
-        splines=ortho;
-        <edge> [shape=rect];
-        <digraph&#58; strict> [shape=rect];
+        <edge> [shape=invhouse];
+        <digraph&#58; strict> [shape=invhouse];
         <node> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
             <TR>
                 <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;node&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;add&#x27;)" TARGET=""
                 ><B>OP:</B> <I>node</I></TD>
             </TR><TR>
-                <TD ALIGN="left" TOOLTIP="&lt;built-in function add&gt;" TARGET=""
-                ><B>FN:</B> _operator.add</TD>
+                <TD ALIGN="left" TOOLTIP="Same as a + b." TARGET=""
+                ><B>FN:</B> &lt;built-in function add&gt;</TD>
             </TR>
         </TABLE>>, shape=plain, tooltip=<node>];
-        <&lt;graph&gt;> [shape=rect];
+        <&lt;graph&gt;> [shape=house];
         <cu&#58;sto&#58;m> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
             <TR>
                 <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;cu:sto:m&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;func&#x27;)" TARGET=""
                 ><B>OP:</B> <I>cu:sto:m</I></TD>
             </TR><TR>
-                <TD ALIGN="left" TOOLTIP="def func():&#10;    pass" TARGET=""
+                <TD ALIGN="left" TOOLTIP="def func(a, b):&#10;    pass" TARGET=""
                 ><B>FN:</B> test.test_plot.func</TD>
             </TR>
         </TABLE>>, shape=plain, tooltip=<cu:sto:m>];
@@ -464,47 +467,51 @@ def test_node_dot_str0(dot_str_pipeline):
     assert _striplines(dot_str) == _striplines(exp)
 
 
+@pytest.mark.xfail(
+    sys.version_info < (3, 7), reason="PY3.6 - has different docstrings for builtins."
+)
 def test_node_dot_str1(dot_str_pipeline, monkeypatch):
     style = get_active_plotter().style
     monkeypatch.setattr(style, "py_item_url_format", "abc#%s")
     monkeypatch.setattr(style, "op_link_target", "_self")
     monkeypatch.setattr(style, "fn_link_target", "bad")
 
-    dot_str = str(dot_str_pipeline.plot())
+    ## Test node-hidding & Graph-overlaying.
+    #
+    overlay = nx.DiGraph()
+    hidden_op = dot_str_pipeline.net.find_op_by_name("node")
+    overlay.add_node(hidden_op, _no_plot=True)
+    overlay.graph["splines"] = "ortho"
+
+    sol = dot_str_pipeline.compute({"edge": 1, "digraph: strict": 2})
+    dot_str = str(sol.plot(graph=overlay))
+
     print(dot_str)
     exp = """
-        digraph graph_ {
+        digraph solution_x5_nodes {
         fontname=italic;
-        label=<graph>;
         splines=ortho;
-        <edge> [shape=rect];
-        <digraph&#58; strict> [shape=rect];
-        <node> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
-            <TR>
-                <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;node&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;add&#x27;)" HREF="abc#{&#x27;dot_path&#x27;: &#x27;_operator.add&#x27;, &#x27;posix_path&#x27;: &#x27;_operator/add&#x27;}" TARGET="bad"
-                ><B>OP:</B> <I>node</I></TD>
-            </TR><TR>
-                <TD ALIGN="left" TOOLTIP="&lt;built-in function add&gt;" HREF="abc#{&#x27;dot_path&#x27;: &#x27;_operator.add&#x27;, &#x27;posix_path&#x27;: &#x27;_operator/add&#x27;}" TARGET="bad"
-                ><B>FN:</B> _operator.add</TD>
-            </TR>
-        </TABLE>>, shape=plain, tooltip=<node>];
-        <&lt;graph&gt;> [shape=rect];
-        <cu&#58;sto&#58;m> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded">
+        subgraph "cluster_after pruning" {
+        label="after pruning";
+        <edge> [fillcolor=wheat, shape=invhouse, style=filled, tooltip="(int) 1"];
+        <digraph&#58; strict> [fillcolor=wheat, shape=invhouse, style=filled, tooltip="(int) 2"];
+        <&lt;graph&gt;> [fillcolor=SkyBlue, shape=house, style=filled, tooltip=None];
+        <cu&#58;sto&#58;m> [label=<<TABLE CELLBORDER="0" CELLSPACING="0" STYLE="rounded" BGCOLOR="wheat">
             <TR>
                 <TD BORDER="1" SIDES="b" ALIGN="left" TOOLTIP="FunctionalOperation(name=&#x27;cu:sto:m&#x27;, needs=[&#x27;edge&#x27;, &#x27;digraph: strict&#x27;], provides=[&#x27;&lt;graph&gt;&#x27;], fn=&#x27;func&#x27;)" HREF="abc#{&#x27;dot_path&#x27;: &#x27;test.test_plot.func&#x27;, &#x27;posix_path&#x27;: &#x27;test/test_plot/func&#x27;}" TARGET="bad"
                 ><B>OP:</B> <I>cu:sto:m</I></TD>
             </TR><TR>
-                <TD ALIGN="left" TOOLTIP="def func():&#10;    pass" HREF="abc#{&#x27;dot_path&#x27;: &#x27;test.test_plot.func&#x27;, &#x27;posix_path&#x27;: &#x27;test/test_plot/func&#x27;}" TARGET="bad"
+                <TD ALIGN="left" TOOLTIP="def func(a, b):&#10;    pass" HREF="abc#{&#x27;dot_path&#x27;: &#x27;test.test_plot.func&#x27;, &#x27;posix_path&#x27;: &#x27;test/test_plot/func&#x27;}" TARGET="bad"
                 ><B>FN:</B> test.test_plot.func</TD>
             </TR>
         </TABLE>>, shape=plain, tooltip=<cu:sto:m>];
-        <edge> -> <node>;
+        }
+
         <edge> -> <cu&#58;sto&#58;m>;
-        <digraph&#58; strict> -> <node>;
         <digraph&#58; strict> -> <cu&#58;sto&#58;m>;
-        <node> -> <&lt;graph&gt;>;
         <cu&#58;sto&#58;m> -> <&lt;graph&gt;>;
         legend [URL="https://graphtik.readthedocs.io/en/latest/_images/GraphtikLegend.svg", fillcolor=yellow, shape=component, style=filled, target=_top];
         }
         """
     assert _striplines(dot_str) == _striplines(exp)
+    assert "<node>" not in dot_str
